@@ -35,6 +35,7 @@ def manage():
     import sys
 
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", "crm.settings")
+    os.environ.setdefault("DJANGO_CONFIGURATION", 'production')
 
     import os
     from dotenv import load_dotenv
@@ -45,5 +46,5 @@ def manage():
 
     os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION'))
 
-    from django.core.management import execute_from_command_line
+    from configurations.management import execute_from_command_line
     execute_from_command_line(sys.argv)
\ No newline at end of file
