@@ -28,7 +28,7 @@ class SentryConfigurationMixin(object):
     @property
     def SENTRY_INSTALLED_APPS(self) -> list:
         return [
-            # 'raven.contrib.django.raven_compat',
+            'raven.contrib.django.raven_compat',
         ]
 
     @property
@@ -38,8 +38,8 @@ class SentryConfigurationMixin(object):
     @property
     def SENTRY_MIDDLEWARE(self):
         return [
-            # 'raven.contrib.django.raven_compat.middleware.Sentry404CatchMiddleware',
-            # 'raven.contrib.django.raven_compat.middleware.SentryResponseErrorIdMiddleware',
+            'raven.contrib.django.raven_compat.middleware.Sentry404CatchMiddleware',
+            'raven.contrib.django.raven_compat.middleware.SentryResponseErrorIdMiddleware',
         ]
 
 
@@ -286,7 +286,8 @@ class BasicConfiguration(Configuration, SentryConfigurationMixin, MailConfigurat
             return values.PathValue(
                 default=os.path.join(self.BASE_DIR, 'static'),
                 environ_name='STATIC_ROOT',
-                environ_prefix='KRYNEGGER'
+                environ_prefix='KRYNEGGER',
+                check_exists=False,
             )
 
     @property
